@@ -1,16 +1,19 @@
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
 #undef PACKAGE
+#undef GETTEXT_PACKAGE
 #undef VERSION
 #undef ENABLE_NLS
 #undef HAVE_CATGETS
 #undef HAVE_GETTEXT
+#undef HAVE_LANGINFO_D_FMT
 #undef HAVE_GMP2_INCLUDE_DIR
 #undef HAVE_LIBSM
 #undef HAVE_PROGRAM_INVOCATION_NAME
 #undef HAVE_PROGRAM_INVOCATION_SHORT_NAME
 #undef HAVE_SHADOW_H
 #undef HAVE_GLIBTOP_MACHINE_H
+#undef HAVE_LIBGTKHTML
 #undef HAVE_LIBGTOP
 #undef NEED_LIBGTOP
 #undef HAVE_GUILE
