@@ -166,12 +166,12 @@ build_search_command (void)
 	file_is_named_utf8 = (gchar *) gtk_entry_get_text (GTK_ENTRY(gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry))));
 
 	if (!file_is_named_utf8 || !*file_is_named_utf8) {
-		file_is_named_locale = NULL;
+		file_is_named_utf8 = g_strdup ("*");
 	} 
 	else {
-		file_is_named_locale = g_locale_from_utf8 (file_is_named_utf8, -1, NULL, NULL, NULL);
 		gnome_entry_prepend_history (GNOME_ENTRY(interface.file_is_named_entry), TRUE, file_is_named_utf8);
 	}
+	file_is_named_locale = g_locale_from_utf8 (file_is_named_utf8, -1, NULL, NULL, NULL);
 	
 	look_in_folder_utf8 = gnome_file_entry_get_full_path (GNOME_FILE_ENTRY(interface.look_in_folder_entry), FALSE);
 	look_in_folder_locale = g_locale_from_utf8 (look_in_folder_utf8, -1, NULL, NULL, NULL);
@@ -201,7 +201,7 @@ build_search_command (void)
 						file_is_named_escaped);
 		} 
 		else {
-			g_string_append_printf (command, "find \"%s\" '!' -type d '!' -type p -name '%s' -xdev -print", 
+			g_string_append_printf (command, "find \"%s\" '!' -type p -name '%s' -xdev -print", 
 						look_in_folder_locale, 
 						file_is_named_escaped);
 		}
@@ -216,12 +216,12 @@ build_search_command (void)
 		search_command.file_is_named_pattern = g_strdup(file_is_named_utf8);
 		
 		if (file_is_named_escaped == NULL) {
-			g_string_append_printf (command, "find \"%s\" '!' -type d '!' -type p -name '%s' ", 
+			g_string_append_printf (command, "find \"%s\" '!' -type p -name '%s' ", 
 					 	look_in_folder_locale,
 						"*");
 		}
 		else {
-			g_string_append_printf (command, "find \"%s\" '!' -type d '!' -type p -name '%s' ", 
+			g_string_append_printf (command, "find \"%s\" '!' -type p -name '%s' ", 
 					 	look_in_folder_locale,
 						file_is_named_escaped);
 		}
@@ -611,7 +611,6 @@ handle_popt_args (void)
 	if (PoptArgument.name != NULL) {
 		gtk_entry_set_text (GTK_ENTRY(gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry))),
 				    g_locale_to_utf8 (PoptArgument.name, -1, NULL, NULL, NULL));
-		gtk_widget_set_sensitive (interface.find_button, TRUE);
 	}
 	if (PoptArgument.path != NULL) {
 		gtk_entry_set_text (GTK_ENTRY(gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry))),
@@ -714,8 +713,10 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		GString      *string;
 		GdkRectangle prior_rect;
 		GdkRectangle after_rect;
+		gint	     look_in_folder_string_length;
 		
 		string = g_string_new (NULL);
+		look_in_folder_string_length = strlen (search_data->look_in_folder);
 
 		while (ioc->is_readable != TRUE);
 
@@ -758,25 +759,28 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 				continue;
 			}
 			
-			if (strncmp (string->str, search_data->look_in_folder, strlen (search_data->look_in_folder)) == 0) { 
+			if (strncmp (string->str, search_data->look_in_folder, look_in_folder_string_length) == 0) { 
 			
-				filename = g_path_get_basename (utf8);
+				if (strlen (string->str) != look_in_folder_string_length) {
+				
+					filename = g_path_get_basename (utf8);
 			
-				if (fnmatch (search_data->file_is_named_pattern, filename, FNM_NOESCAPE) != FNM_NOMATCH) {
-					if (search_data->show_hidden_files == TRUE) {
-						if (search_data->regex_matching_enabled == FALSE) {
-							add_file_to_search_results (string->str, interface.model, &interface.iter);
-						} 
-						else if (compare_regex (search_data->regex_string, filename) == TRUE) {
-							add_file_to_search_results (string->str, interface.model, &interface.iter);
+					if (fnmatch (search_data->file_is_named_pattern, filename, FNM_NOESCAPE) != FNM_NOMATCH) {
+						if (search_data->show_hidden_files == TRUE) {
+							if (search_data->regex_matching_enabled == FALSE) {
+								add_file_to_search_results (string->str, interface.model, &interface.iter);
+							} 
+							else if (compare_regex (search_data->regex_string, filename) == TRUE) {
+								add_file_to_search_results (string->str, interface.model, &interface.iter);
+							}
 						}
-					}
-					else if (is_path_hidden (string->str) == FALSE) {
-						if (search_data->regex_matching_enabled == FALSE) {
-							add_file_to_search_results (string->str, interface.model, &interface.iter);
-						} 
-						else if (compare_regex (search_data->regex_string, filename) == TRUE) {
-							add_file_to_search_results (string->str, interface.model, &interface.iter);
+						else if (is_path_hidden (string->str) == FALSE) {
+							if (search_data->regex_matching_enabled == FALSE) {
+								add_file_to_search_results (string->str, interface.model, &interface.iter);
+							} 
+							else if (compare_regex (search_data->regex_string, filename) == TRUE) {
+								add_file_to_search_results (string->str, interface.model, &interface.iter);
+							}
 						}
 					}
 				}
@@ -1215,18 +1219,16 @@ GtkWidget *
 create_search_results_section (void)
 {
 	GtkWidget 	  *label;
-	GtkWidget 	  *frame;	
+	GtkWidget 	  *vbox;
 	GtkWidget 	  *window;	
 	GtkTreeViewColumn *column;	
 	GtkCellRenderer   *renderer;
 	
-	frame = gtk_frame_new (NULL);
-	gtk_frame_set_shadow_type (GTK_FRAME(frame), GTK_SHADOW_NONE); 
+	vbox = gtk_vbox_new (FALSE, 0);
 	
 	label = gtk_label_new_with_mnemonic (_("S_earch Results"));
-	gtk_label_set_justify (GTK_LABEL(label), GTK_JUSTIFY_LEFT);
 	g_object_set (G_OBJECT(label), "xalign", 0.0, NULL);
-	gtk_frame_set_label_widget (GTK_FRAME(frame), label);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
 	
 	window = gtk_scrolled_window_new (NULL, NULL); 
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(window), GTK_SHADOW_IN);	
@@ -1291,7 +1293,7 @@ create_search_results_section (void)
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), interface.tree);
 	
 	gtk_container_add (GTK_CONTAINER(window), GTK_WIDGET(interface.tree));
-	gtk_container_add (GTK_CONTAINER(frame), GTK_WIDGET(window));
+	gtk_box_pack_end (GTK_BOX (vbox), window, TRUE, TRUE, 0);
 	
 	/* create the name column */
 	column = gtk_tree_view_column_new ();
@@ -1354,7 +1356,7 @@ create_search_results_section (void)
 	gtk_tree_view_column_set_sort_column_id (column, COLUMN_DATE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(interface.tree), column);
 
-	return frame;
+	return vbox;
 }
 
 GtkWidget *
@@ -1392,7 +1394,7 @@ create_main_window (void)
 	interface.file_is_named_entry = gnome_entry_new ("gsearchtool-file-entry");
 	gtk_label_set_mnemonic_widget (GTK_LABEL(label), gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry)));
 	gnome_entry_set_max_saved (GNOME_ENTRY(interface.file_is_named_entry), 10);
-	gtk_table_attach (GTK_TABLE(interface.table), interface.file_is_named_entry, 1, 2, 0, 1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+	gtk_table_attach (GTK_TABLE(interface.table), interface.file_is_named_entry, 1, 2, 0, 1, GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
 	entry =  gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry));
        
 	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(interface.file_is_named_entry)))
@@ -1422,7 +1424,7 @@ create_main_window (void)
 	entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry));
 	gtk_label_set_mnemonic_widget (GTK_LABEL(label), entry);
 	folder_entry = gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry));
-	gtk_table_attach (GTK_TABLE(interface.table), interface.look_in_folder_entry, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+	gtk_table_attach (GTK_TABLE(interface.table), interface.look_in_folder_entry, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL | GTK_SHRINK, 0, 0, 0);
 	
 	if (interface.is_gail_loaded)
 	{ 
@@ -1485,7 +1487,7 @@ create_main_window (void)
 	gtk_box_pack_end (GTK_BOX(hbox), interface.stop_button, FALSE, FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_end (GTK_BOX(hbox), interface.find_button, FALSE, FALSE, GNOME_PAD_SMALL);
 	gtk_widget_set_sensitive (interface.stop_button, FALSE);
-	gtk_widget_set_sensitive (interface.find_button, FALSE);
+	gtk_widget_set_sensitive (interface.find_button, TRUE);
 	
 	if (interface.is_gail_loaded)
 	{
